@@ -40,7 +40,6 @@ file if there are some entries, or ``None`` to create an empty changelog::
      * Some change
     <BLANKLINE>
      -- John Doe <joe@example.com>  Wed, 31 Mar 2021 20:31:55 -0000
-    <BLANKLINE>
 
 
 If you have the full contents of a changelog, but are only interested in the
@@ -98,10 +97,10 @@ Changelog Classes
 # and licensed under the same license as above.
 
 import email.utils
+import logging
 import os
 import re
 import socket
-import warnings
 
 # pwd is only available on Unix platforms.
 try:
@@ -140,6 +139,9 @@ except ImportError:
 from debian.debian_support import Version
 
 
+logger = logging.getLogger('debian.changelog')
+
+
 class ChangelogParseError(Exception):
     """Indicates that the changelog could not be parsed"""
     is_user_error = True
@@ -489,7 +491,7 @@ class Changelog(object):
         # type: (str, bool) -> None
         if strict:
             raise ChangelogParseError(message)
-        warnings.warn(message)
+        logger.warning(message)
 
     def parse_changelog(self,
                         file,             # type: Optional[IterableDataSource]
@@ -897,7 +899,9 @@ be uploaded."""
         block = ChangeBlock(package, version, distributions,
                             urgency, urgency_comment,
                             changes, author, date, other_pairs, encoding)
-        block.add_trailing_line('')
+        if self._blocks:
+            # #998715 - only add a trailing line if there are other blocks.
+            block.add_trailing_line('')
         self._blocks.insert(0, block)
 
     def write_to_open_file(self, filehandle):
@@ -965,11 +969,8 @@ def get_maintainer():
     else:
         addr = None
         if os.path.exists('/etc/mailname'):
-            f = open('/etc/mailname')
-            try:
+            with open('/etc/mailname', encoding="UTF-8") as f:
                 addr = f.readline().strip()
-            finally:
-                f.close()
         if not addr:
             addr = socket.getfqdn()
         if addr:
